.. _tutorial-index:

############
 Tutorials
############

This section contains various tutorials that will help the reader get a
feeling of Camelot. We assume that the reader has some knowledge of `Python
<http://www.python.org>`_.

The reader can read the following sub-sections in any order.

.. toctree::

   videostore.rst
   reporting.rst
   document_merge.rst
